"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.basicAuthMiddleware = void 0;
const credentials_1 = require("../credentials");
const basicAuthMiddleware = (allowedCredentials) => {
    return async (ctx, next) => {
        // 没有设置用户，则按未开启处理
        if (!allowedCredentials || allowedCredentials.length === 0) {
            await next();
            return;
        }
        const url = new URL(ctx.href);
        let credentials = null;
        if (url.username && url.password) {
            credentials = new credentials_1.Credentials(url.username, url.password);
        }
        else if (ctx.get('Authorization') !== '') {
            credentials = (0, credentials_1.buildFromAuthorization)(ctx.get('Authorization'));
        }
        if (credentials === null) {
            ctx.status = 401;
            ctx.set('WWW-Authenticate', 'Basic realm="Authorization Required"');
            return;
        }
        const ac = allowedCredentials.find(ac => ac.username === credentials.username);
        if (!ac || ac.password !== credentials.password) {
            ctx.status = 401;
            ctx.set('WWW-Authenticate', 'Basic realm="Authorization Required"');
            return;
        }
        await next();
    };
};
exports.basicAuthMiddleware = basicAuthMiddleware;
//# sourceMappingURL=basic-auth.js.map